@@ -1,53 +1,28 @@
 package Class::Load;
 {
-  $Class::Load::VERSION = '0.11';
+  $Class::Load::VERSION = '0.14';
 }
 use strict;
 use warnings;
 use base 'Exporter';
 use Data::OptList 'mkopt';
-use Module::Runtime qw(check_module_name module_notional_filename
-                       require_module use_module);
+use Module::Implementation;
+use Module::Runtime 0.011 qw(
+    check_module_name
+    module_notional_filename
+    require_module
+    use_module
+);
 use Package::Stash;
 use Try::Tiny;
 
-our $IMPLEMENTATION;
+{
+    my $loader = Module::Implementation::build_loader_sub(
+        implementations => [ 'XS', 'PP' ],
+        symbols         => ['is_class_loaded'],
+    );
 
-BEGIN {
-    $IMPLEMENTATION = $ENV{CLASS_LOAD_IMPLEMENTATION}
-        if exists $ENV{CLASS_LOAD_IMPLEMENTATION};
-
-    my $err;
-    if ($IMPLEMENTATION) {
-        if (!try { require_module("Class::Load::$IMPLEMENTATION") }) {
-            require Carp;
-            Carp::croak("Could not load Class::Load::$IMPLEMENTATION: $@");
-        }
-    }
-    else {
-        for my $impl ('XS', 'PP') {
-            if (try { require_module("Class::Load::$impl") }) {
-                $IMPLEMENTATION = $impl;
-                last;
-            }
-            else {
-                $err .= $@;
-            }
-        }
-    }
-
-    if (!$IMPLEMENTATION) {
-        require Carp;
-        Carp::croak("Could not find a suitable Class::Load implementation: $err");
-    }
-
-    my $impl = "Class::Load::$IMPLEMENTATION";
-    my $stash = Package::Stash->new(__PACKAGE__);
-    $stash->add_symbol('&is_class_loaded' => $impl->can('is_class_loaded'));
-
-    sub _implementation {
-        return $IMPLEMENTATION;
-    }
+    $loader->();
 }
 
 our @EXPORT_OK = qw/load_class load_optional_class try_load_class is_class_loaded load_first_existing_class/;
@@ -231,7 +206,7 @@ Class::Load - a working (require "Class::Name") and more
 
 =head1 VERSION
 
-version 0.11
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -364,7 +339,7 @@ Shawn M Moore <sartak at bestpractical.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Shawn M Moore.
+This software is copyright (c) 2012 by Shawn M Moore.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
